<?php
/**
 * Kids Online Store Theme Customizer
 *
 * @link: https://developer.wordpress.org/themes/customize-api/customizer-objects/
 *
 * @package Kids Online Store
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function kids_online_store_customize_register($wp_customize){
    $wp_customize->get_setting('blogname')->transport = 'postMessage';
    $wp_customize->get_setting('blogdescription')->transport = 'postMessage';
    $wp_customize->get_setting('header_textcolor')->transport = 'postMessage';

    if (isset($wp_customize->selective_refresh)) {
        // Site title
        $wp_customize->selective_refresh->add_partial('blogname', array(
            'selector' => '.site-title',
            'render_callback' => 'kids_online_store_customize_partial_blogname',
        ));
    }

    // Top Header
    $wp_customize->add_section('kids_online_store_top_header',array(
        'title' => esc_html__('Top Header','kids-online-store'),
    ));

    $wp_customize->add_setting('kids_online_store_phone_number_info',array(
        'default' => '',
        'sanitize_callback' => 'kids_online_store_sanitize_phone_number'
    )); 
    $wp_customize->add_control('kids_online_store_phone_number_info',array(
        'label' => esc_html__('Phone Number','kids-online-store'),
        'section' => 'kids_online_store_top_header',
        'setting' => 'kids_online_store_phone_number_info',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('kids_online_store_email_info',array(
        'default' => '',
        'sanitize_callback' => 'kids_online_store_sanitize_email'
    )); 
    $wp_customize->add_control('kids_online_store_email_info',array(
        'label' => esc_html__('Email Address','kids-online-store'),
        'section' => 'kids_online_store_top_header',
        'setting' => 'kids_online_store_email_info',
        'type'  => 'text'
    ));

    // Social Link
    $wp_customize->add_section('kids_online_store_social_link',array(
        'title' => esc_html__('Social Links','kids-online-store'),
    ));

    $wp_customize->add_setting('kids_online_store_facebook_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    )); 
    $wp_customize->add_control('kids_online_store_facebook_url',array(
        'label' => esc_html__('Facebook Link','kids-online-store'),
        'section' => 'kids_online_store_social_link',
        'setting' => 'kids_online_store_facebook_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('kids_online_store_twitter_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    )); 
    $wp_customize->add_control('kids_online_store_twitter_url',array(
        'label' => esc_html__('Twitter Link','kids-online-store'),
        'section' => 'kids_online_store_social_link',
        'setting' => 'kids_online_store_twitter_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('kids_online_store_intagram_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    )); 
    $wp_customize->add_control('kids_online_store_intagram_url',array(
        'label' => esc_html__('Intagram Link','kids-online-store'),
        'section' => 'kids_online_store_social_link',
        'setting' => 'kids_online_store_intagram_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('kids_online_store_linkedin_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    )); 
    $wp_customize->add_control('kids_online_store_linkedin_url',array(
        'label' => esc_html__('Linkedin Link','kids-online-store'),
        'section' => 'kids_online_store_social_link',
        'setting' => 'kids_online_store_linkedin_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('kids_online_store_pintrest_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    )); 
    $wp_customize->add_control('kids_online_store_pintrest_url',array(
        'label' => esc_html__('Pinterest Link','kids-online-store'),
        'section' => 'kids_online_store_social_link',
        'setting' => 'kids_online_store_pintrest_url',
        'type'  => 'url'
    ));

    //Slider
    $wp_customize->add_section('kids_online_store_top_slider',array(
        'title' => esc_html__('Slider Settings','kids-online-store'),
        'description' => esc_html__('Here you have to add 3 different pages in below dropdown. Note: Image Dimensions 1200 x 550 px','kids-online-store')
    ));

    for ( $count = 1; $count <= 3; $count++ ) {

        $wp_customize->add_setting( 'kids_online_store_top_slider_page' . $count, array(
            'default'           => '',
            'sanitize_callback' => 'kids_online_store_sanitize_dropdown_pages'
        ) );
        $wp_customize->add_control( 'kids_online_store_top_slider_page' . $count, array(
            'label'    => __( 'Select Slide Page', 'kids-online-store' ),
            'section'  => 'kids_online_store_top_slider',
            'type'     => 'dropdown-pages'
        ) );
    }

    // Footer
    $wp_customize->add_section('kids_online_store_site_footer_section', array(
        'title' => esc_html__('Footer', 'kids-online-store'),
    ));

    $wp_customize->add_setting('kids_online_store_footer_text_setting', array(
        'sanitize_callback' => 'sanitize_text_field',
    ));
    $wp_customize->add_control('kids_online_store_footer_text_setting', array(
        'label' => __('Replace the footer text', 'kids-online-store'),
        'section' => 'kids_online_store_site_footer_section',
        'priority' => 1,
        'type' => 'text',
    ));
}
add_action('customize_register', 'kids_online_store_customize_register');

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function kids_online_store_customize_partial_blogname(){
    bloginfo('name');
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function kids_online_store_customize_partial_blogdescription(){
    bloginfo('description');
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function kids_online_store_customize_preview_js(){
    wp_enqueue_script('kids-online-store-customizer', esc_url(get_template_directory_uri()) . '/assets/js/customizer.js', array('customize-preview'), '20151215', true);
}
add_action('customize_preview_init', 'kids_online_store_customize_preview_js');